Results
=======

This page will contain results from Beampy.


.. figure:: interface/results_array.png
   :alt: Array of guides results
   
   Array of guides results


.. figure:: interface/results_curved.png
   :alt: Curved guides results
   
   Curved guides results
   

.. figure:: interface/results_soliton.png
   :alt: Soliton results
   
   Soliton results


.. figure:: results/airy.png
   :alt: Airy beam
   
   Airy beam results
